==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PeerAuthenticationMethodFluentImpl.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public class PeerAuthenticationMethodFluentImpl<A extends PeerAuthenticationMethodFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PeerAuthenticationMethodFluent<A>{

    private VisitableBuilder<? extends me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params,?> params;

    public PeerAuthenticationMethodFluentImpl(){
    }
    public PeerAuthenticationMethodFluentImpl(PeerAuthenticationMethod instance){
            this.withParams(instance.getParams()); 
    }

    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params getParams(){
            return this.params!=null?this.params.build():null;
    }

    public me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params buildParams(){
            return this.params!=null?this.params.build():null;
    }

    public A withParams(me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params params){
            if (params instanceof JwtParams){ this.params= new JwtParamsBuilder((JwtParams)params); _visitables.add(this.params);}
            if (params instanceof MtlsParams){ this.params= new MtlsParamsBuilder((MtlsParams)params); _visitables.add(this.params);}
            return (A) this;
    }

    public Boolean hasParams(){
            return this.params != null;
    }

    public A withJwtParams(JwtParams jwtParams){
            _visitables.remove(this.params);
            if (jwtParams!=null){ this.params= new JwtParamsBuilder(jwtParams); _visitables.add(this.params);} return (A) this;
    }

    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParams(){
            return new JwtParamsNestedImpl();
    }

    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParamsLike(JwtParams item){
            return new JwtParamsNestedImpl(item);
    }

    public A withMtlsParams(MtlsParams mtlsParams){
            _visitables.remove(this.params);
            if (mtlsParams!=null){ this.params= new MtlsParamsBuilder(mtlsParams); _visitables.add(this.params);} return (A) this;
    }

    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParams(){
            return new MtlsParamsNestedImpl();
    }

    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParamsLike(MtlsParams item){
            return new MtlsParamsNestedImpl(item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PeerAuthenticationMethodFluentImpl that = (PeerAuthenticationMethodFluentImpl) o;
            if (params != null ? !params.equals(that.params) :that.params != null) return false;
            return true;
    }


    public class JwtParamsNestedImpl<N> extends JwtParamsFluentImpl<PeerAuthenticationMethodFluent.JwtParamsNested<N>> implements PeerAuthenticationMethodFluent.JwtParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final JwtParamsBuilder builder;
    
            JwtParamsNestedImpl(JwtParams item){
                    this.builder = new JwtParamsBuilder(this, item);
            }
            JwtParamsNestedImpl(){
                    this.builder = new JwtParamsBuilder(this);
            }
    
    public N and(){
            return (N) PeerAuthenticationMethodFluentImpl.this.withJwtParams(builder.build());
    }
    public N endJwtParams(){
            return and();
    }

}
    public class MtlsParamsNestedImpl<N> extends MtlsParamsFluentImpl<PeerAuthenticationMethodFluent.MtlsParamsNested<N>> implements PeerAuthenticationMethodFluent.MtlsParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final MtlsParamsBuilder builder;
    
            MtlsParamsNestedImpl(MtlsParams item){
                    this.builder = new MtlsParamsBuilder(this, item);
            }
            MtlsParamsNestedImpl(){
                    this.builder = new MtlsParamsBuilder(this);
            }
    
    public N and(){
            return (N) PeerAuthenticationMethodFluentImpl.this.withMtlsParams(builder.build());
    }
    public N endMtlsParams(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PeerAuthenticationMethodFluentImpl.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public class PeerAuthenticationMethodFluentImpl<A extends PeerAuthenticationMethodFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PeerAuthenticationMethodFluent<A>{

    private VisitableBuilder<? extends PeerAuthenticationMethod.Params,?> params;

    public PeerAuthenticationMethodFluentImpl(){
    }
    public PeerAuthenticationMethodFluentImpl(PeerAuthenticationMethod instance){
            this.withParams(instance.getParams()); 
    }

    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public PeerAuthenticationMethod.Params getParams(){
            return this.params!=null?this.params.build():null;
    }

    public PeerAuthenticationMethod.Params buildParams(){
            return this.params!=null?this.params.build():null;
    }

    public A withParams(PeerAuthenticationMethod.Params params){
            if (params instanceof JwtParams){ this.params= new JwtParamsBuilder((JwtParams)params); _visitables.get("params").add(this.params);}
            if (params instanceof MtlsParams){ this.params= new MtlsParamsBuilder((MtlsParams)params); _visitables.get("params").add(this.params);}
            return (A) this;
    }

    public Boolean hasParams(){
            return this.params != null;
    }

    public A withJwtParams(JwtParams jwtParams){
            _visitables.get("params").remove(this.params);
            if (jwtParams!=null){ this.params= new JwtParamsBuilder(jwtParams); _visitables.get("params").add(this.params);} return (A) this;
    }

    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParams(){
            return new JwtParamsNestedImpl();
    }

    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParamsLike(JwtParams item){
            return new JwtParamsNestedImpl(item);
    }

    public A withMtlsParams(MtlsParams mtlsParams){
            _visitables.get("params").remove(this.params);
            if (mtlsParams!=null){ this.params= new MtlsParamsBuilder(mtlsParams); _visitables.get("params").add(this.params);} return (A) this;
    }

    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParams(){
            return new MtlsParamsNestedImpl();
    }

    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParamsLike(MtlsParams item){
            return new MtlsParamsNestedImpl(item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            PeerAuthenticationMethodFluentImpl that = (PeerAuthenticationMethodFluentImpl) o;
            if (params != null ? !params.equals(that.params) :that.params != null) return false;
            return true;
    }


    public class JwtParamsNestedImpl<N> extends JwtParamsFluentImpl<PeerAuthenticationMethodFluent.JwtParamsNested<N>> implements PeerAuthenticationMethodFluent.JwtParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final JwtParamsBuilder builder;
    
            JwtParamsNestedImpl(JwtParams item){
                    this.builder = new JwtParamsBuilder(this, item);
            }
            JwtParamsNestedImpl(){
                    this.builder = new JwtParamsBuilder(this);
            }
    
    public N and(){
            return (N) PeerAuthenticationMethodFluentImpl.this.withJwtParams(builder.build());
    }
    public N endJwtParams(){
            return and();
    }

}
    public class MtlsParamsNestedImpl<N> extends MtlsParamsFluentImpl<PeerAuthenticationMethodFluent.MtlsParamsNested<N>> implements PeerAuthenticationMethodFluent.MtlsParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final MtlsParamsBuilder builder;
    
            MtlsParamsNestedImpl(MtlsParams item){
                    this.builder = new MtlsParamsBuilder(this, item);
            }
            MtlsParamsNestedImpl(){
                    this.builder = new MtlsParamsBuilder(this);
            }
    
    public N and(){
            return (N) PeerAuthenticationMethodFluentImpl.this.withMtlsParams(builder.build());
    }
    public N endMtlsParams(){
            return and();
    }

}


}
